ADMIN_ADDRESS = 0x032611AA4C7610D0B6306ADFFA27BF3E8774D1A27C3E9F93CDC2F7BCFEC0C3D7
ORACLE_CONTROLLER_ADDRESS = (
    0x013BEFE6EDA920CE4AF05A50A67BD808D67EEE6BA47BB0892BEF2D630EAF1BBA
)
PUBLISHER_REGISTRY_ADDRESS = (
    0x07E05E4DEA8A62988D9A06EA47BDAC34C759A413DB5B358E4A3A3D691D9D89E4
)
NETWORK = "testnet"
DEFAULT_AGGREGATION_MODE = 0
